@@ -92,7 +92,11 @@ def parse_toml():
         elif meta_path.suffix == ".jsonl":
             args["metadata"] = pd.read_json(meta_path, lines=True)
         else:
-            print("Extension of " + meta_path.suffix + " not one of .csv or .parquet")
+            print(
+                "Extension of "
+                + meta_path.suffix
+                + " not one of .csv, .jsonl, or .parquet"
+            )
             sys.exit(1)
 
     if "functions" in args:
